--[[ 
Title: LootMyFish
Notes: Enables autolooting when you start fishing and disables it afterwards.
Author: Naranja
Version: 1.4
]]--

LootMyFish = {}

function LootMyFish.new()
	local self = {}
	
	--[[ Private variables ]]--
	local frame = nil
	
	--[[ Public variables ]]--
	self.enabled = false
	self.chatColor = "00E0DE55"
	
	--[[ Private methods ]]--
	-- Prints a message to the default chat log
	local function printMessage(msg)
		DEFAULT_CHAT_FRAME:AddMessage("|c" .. self.chatColor .. msg)
	end
	
	-- Toggles autolooting
	local function toggleAutoloot(enable)
		if (enable) then
			--printMessage("Autolooting: On")
			SetCVar("autoLootDefault", "1")
		else
			--printMessage("Autolooting: Off")
			SetCVar("autoLootDefault", "0")
		end
	end
	
	-- Handles and dispatches all incoming events	
	local function onEvent(frameObj, event, ...)
		-- Show onload message and start addon
		if event == "ADDON_LOADED" then
			local addonName = ...
			if addonName == "LootMyFish" then
				self.enabled = true
				printMessage("LootMyFish Loaded. (/lmf)")
			end
		end

		-- Return when addon is disabled
		if not self.enabled then return end
		
		-- Handle player started fishing event
		if event == "UNIT_SPELLCAST_CHANNEL_START" then
			local unit, spell, rank, lineID, spellID = ...
			if unit == "player" and spell == "Fishing" then
				toggleAutoloot(true)
			end
		end
		
		-- Handle player stopped fishing event
		if event == "UNIT_SPELLCAST_CHANNEL_STOP" then
			local unit, spell, rank, lineID, spellID = ...
			if unit == "player" and spell == "Fishing" then
				toggleAutoloot(false)
			end
		end
	end
	
	-- Handle /lmf slashcommand
	local function slashHandler(msg, editbox)
		if type(msg) ~= "string" then return end
		-- enable
		if msg == 'enable' then
			if not self.enabled then
				self.enabled = true
				printMessage("LootMyFish enabled.")
			else
				printMessage("LootMyFish already enabled.")
			end
		-- disable
		elseif msg == 'disable' then
			if self.enabled then
				self.enabled = false
				printMessage("LootMyFish disabled.")
			else
				printMessage("LootMyFish already disabled.")
			end
		-- default
		else
			printMessage("Usage: /lmf [enable | disable]")
		end
	end
		
	--[[ Public methods	 ]]--
	-- Initializes lmf on a frame and registers on events
	function self.init(frameName)
		-- Create frame
		frame = CreateFrame("Frame", frameName)
		-- Register events
		frame:RegisterEvent("ADDON_LOADED")
		frame:RegisterEvent("UNIT_SPELLCAST_CHANNEL_START")
		frame:RegisterEvent("UNIT_SPELLCAST_CHANNEL_STOP")
		frame:SetScript("OnEvent", onEvent)
		-- Register and assign /lmf slash command
		SLASH_LOOTMYFISH1 = '/lmf'
		SlashCmdList["LOOTMYFISH"] = slashHandler
	end
	
	return self
end

lmf = LootMyFish.new()
lmf.init("LootMyFishFrame")